管理 Block Storage for Classic 中的卷冊 IBM Cloud

透過 IBM Cloud 控制台、命令列介面 (CLI)、API 或 Terraform 管理 Block Storage for Classic 儲存卷,以設定、監控及控制您的區塊儲存資源。

在主控台檢視 Block Storage for Classic 磁碟區的詳細資訊

您可以檢視所選儲存卷的關鍵資訊摘要,其中包含已新增至該儲存卷的快照與複寫功能。

  1. 前往 IBM Cloud® 控制台。 從 選單 選單圖示,選擇 基礎建設 VPC 圖示 > 經典基礎建設。
  2. 點選「儲存空間」> Block Storage for Classic。 顯示區塊磁碟區清單。
  3. 您可以按一下篩選器圖示,然後選擇位置或輸入特定容量來篩選清單。 請按「套用」以確認您的選擇。
  4. 從清單中按一下適當的磁區名稱。

您可以按一下 Download 下載圖示,下載 CSV 格式的清單。

從 CLI 檢視 Block Storage for Classic 磁碟區的詳細資訊

開始之前,請決定您要使用的 CLI 用戶端。

從 IBMCLOUD CLI 檢視 Block Storage for Classic 磁碟區詳細資料

  1. 使用 ibmcloud sl block volume-list 指令檢視可用儲存磁碟區清單。 在輸出中找到音量。 您可以依 id, username, datacenter, storage_type, capacity_gb, bytes_used, ip_addr, lunId, active_transactions,和 created_by 值對清單排序。

    • 以下範例擷取磁碟區清單,輸出會依名稱將磁碟區排序,最近建立的磁碟區排在最前面。
      ibmcloud sl block volume-list --sortby username
      
    • 以下範例擷取依特定順序建立的磁碟區清單。
      $ ibmcloud sl block volume-list --order 110758744
      id        username            datacenter   storage_type             capacity_gb   bytes_used   IOPs   ip_addr     lunId  active_transactions   rep_partner_count   notes
      562193766 SL02SEL1414935-675  dal09        endurance_block_storage  80            -            -      10.2.125.62 0      0                     0                   -
      
  2. 使用 ibmcloud sl block volume-detail 指令,從 CLI 檢視特定區塊磁區的詳細資料。

    $ ibmcloud sl block volume-detail  562193766
    Name                       Value
    ID                         562193766
    User name                  SL02SEL1414935-675
    Type                       endurance_block_storage
    Capacity (GB)              80
    LUN Id                     0
    Endurance Tier             LOW_INTENSITY_TIER
    Endurance Tier Per IOPS    0.25
    Datacenter                 dal09
    Target IP                  10.2.125.62
    Snapshot Size (GB)         20
    Snapshot Used (Bytes)      -
    # of Active Transactions   0
    Replicant Count            0
    Notes                      -
    

有關這些命令可用的所有參數的更多信息,請參閱 ibmcloud sl blockvolume-detail 和 ibmcloud sl blockvolume-list。

從 SLCLI 檢視 Block Storage for Classic 磁碟區詳細資料

若要檢視儲存磁碟區的相關資訊,您可以從 CLI 使用下列指令。

  1. 使用 slcli block volume-list 指令列出可用的儲存磁碟區,並使用其中一個可用的篩選器來協助找出您感興趣的磁碟區。 以下範例指令依據訂單 ID 列出磁碟區。

    slcli block volume-list --order ORDER_ID
    
  2. 使用第一個指令輸出的磁碟區 ID 執行 slcli block volume-detail 指令。

    $ slcli block volume-detail --help
    Usage: slcli block volume-detail [OPTIONS] VOLUME_ID
    Options:
      -h, --help  Show this message and exit.
    

如需這些指令可用參數的詳細資訊,請參閱 block volume-detail 和 block volume-list。

在控制台中更新音量的註解

  1. 前往 IBM Cloud® 控制台。 從功能表中,選取 Infrastructure VPC 圖示 > Classic Infrastructure。
  2. 點選「儲存空間」> Block Storage for Classic。
  3. 請找到您要更新的磁碟。 按一下磁碟區名稱,檢視磁碟區詳細資料頁。
  4. 按一下 注意事項 旁邊的 編輯圖示 編輯圖示,然後輸入您的文字。

從 CLI 更新磁碟區的備註

您可以使用 ibmcloud sl call-api 指令新增和修改磁碟區的備註。

$ ibmcloud sl call-api --help
NAME:
  call-api - Call arbitrary API endpoints
USAGE:
  ibmcloud sl call-api SERVICE METHOD [OPTIONS]
OPTIONS:
  --filter value      Object filters
  -h, --help          Usage information.
  --init value        Init parameter
  --limit value       Result limit
  --mask value        Object mask: use to limit fields returned
  --offset value      Result offset
  --output value      Specify output format, only JSON is supported now.
  --parameters value  Append parameters to web call

在 --init 選項中指定音量 ID,並使用 --parameters 選項設定新筆記。 請參閱下列範例:

ibmcloud sl call-api SoftLayer_Network_Storage editObject --init 562193766 --parameters '[{"notes":"Testing."}]'

如需詳細資訊,請參閱 ibmcloud sl call-api。

授權主機存取Block Storage for Classic在控制台中

「授權」主機是指被授予存取特定卷的權限的主機。 如果沒有主機授權,則無法從系統中存取或使用儲存空間。 授權主機存取您的磁碟卷會產生使用者名稱、密碼以及「iSCSI」合格名稱 (IQN),這些資訊是掛載多路徑 I/O (MPIO) iSCSI 連線所必需的。

您可以授權及連接與儲存空間位於相同資料中心的主機。 您可以有多個帳戶,但無法授權某個帳戶的主機存取您在另一個帳戶上的儲存空間。

  1. 點選「儲存空間」> Block Storage for Classic。
  2. 找出磁區,然後按一下省略符號 「動作」圖示。
  3. 按一下授權主機。
  4. 若要查看可用裝置或 IP 位址的清單,請選取您要根據裝置類型還是子網路來授權存取。
    • 若您選擇「裝置」選項,則可從「Bare Metal Server」或虛擬伺服器實例中進行選擇。
    • 如果選擇 IP 位址選項,請選擇計算主機的子網路。
  5. 從已過濾的清單中,選取可以存取磁區的一個以上主機,然後按一下儲存。

每個區塊磁區的授權數目預設限制是 8。 這表示最多可授權 8 台主機存取 Block Storage for Classic 磁碟區。 在 VMWare 部署中使用 Block Storage for Classic 的客戶,可以要求將授權限制提高到 64。 若要要求增加限制,請提出 支援案例。

授權主機從 CLI 存取 Block Storage for Classic

「授權」主機是指被授予存取特定卷的權限的主機。 如果沒有主機授權,則無法從系統中存取或使用儲存空間。 授權主機存取您的磁碟區時,系統會產生使用者名稱和密碼。

您可以授權及連接與儲存空間位於相同資料中心的主機。 您可以有多個帳戶,但無法授權某個帳戶的主機存取您在另一個帳戶上的儲存空間。

從 IBMCLOUD CLI 授權主機

使用 ibmcloud sl block access-authorize 指令來授權主機存取磁區。 下列範例授權虛擬伺服器實例 87654321 裝載磁區 12345678。

ibmcloud sl block access-authorize 12345678 --virtual-id 87654321

如需此指令可用的所有參數的相關資訊,請參閱 ibmcloud sl block access-authorize。

您也可以使用下列指令來指定容許存取儲存空間的 Compute 實例子網路。

ibmcloud sl block subnets-assign --subnet-id 1234 87654321

從 SLCLI 授權主機

若要授權主機存取磁區,您可以使用下列指令。

$ slcli block access-authorize --help
Usage: slcli block access-authorize [OPTIONS] VOLUME_ID
Options:
  -h, --hardware-id TEXT    The ID of a hardware server to authorize.
  -v, --virtual-id TEXT     The ID of a virtual server to authorize.
  -i, --ip-address-id TEXT  The ID of an IP address to authorize.
  -p, --ip-address TEXT     An IP address to authorize.
  --help                    Show this message and exit.
$ slcli block subnets-list -h
Usage: slcli block subnets-list [OPTIONS] ACCESS_ID
  List block storage assigned subnets for the given host id.
  access_id is the host_id obtained by: slcli block access-list <volume_id>
Options:
    -h, --help  Show this message and exit.
$ slcli block subnets-assign -h
Usage: slcli block subnets-assign [OPTIONS] ACCESS_ID
  Assign block storage subnets to the given host id.
  access_id is the host_id obtained by: slcli block access-list <volume_id>
Options:
  --subnet-id INTEGER  ID of the subnets to assign; e.g.: --subnet-id 1234
  -h, --help           Show this message and exit.
$ slcli block subnets-remove -h
Usage: slcli block subnets-remove [OPTIONS] ACCESS_ID
  Remove block storage subnets for the given host id.
  access_id is the host_id obtained by: slcli block access-list <volume_id>
Options:
  --subnet-id INTEGER  ID of the subnets to remove; e.g.: --subnet-id 1234
  -h, --help           Show this message and exit.

每個區塊磁區的授權數目預設限制是 8。 這表示最多可授權 8 台主機存取 Block Storage for Classic 磁碟區。 在 VMWare 部署中使用 Block Storage for Classic 的客戶,可以要求將授權限制提高到 64。 若要要求增加限制,請提出 支援案例。

授權主機使用 Terraform 存取 Block Storage for Classic

「授權」主機是指被授予存取特定卷的權限的主機。 如果沒有主機授權,則無法從系統中存取或使用儲存空間。 授權主機存取您的磁碟卷會產生使用者名稱、密碼以及「iSCSI」合格名稱 (IQN),這些資訊是掛載多路徑 I/O (MPIO) iSCSI 連線所必需的。

您可以授權及連接與儲存空間位於相同資料中心的主機。 您可以有多個帳戶,但無法授權某個帳戶的主機存取您在另一個帳戶上的儲存空間。

若要授權計算主機存取磁區,請使用 ibm_storage_block 資源並指定 allowed_virtual_guest_ids (若為虛擬伺服器) 或 allowed_hardware_ids (若為裸機伺服器)。 指定 allowed_ip_addresses 以定義哪些 IP 位址可以存取儲存體。

下列範例定義 ID 為 27699397 的虛擬伺服器可以從 10.40.98.193 10.40.98.200 位址存取磁區。

resource "ibm_storage_block" "test1" {
        type = "Endurance"
        datacenter = "dal09"
        capacity = 40
        iops = 4
        os_format_type = "Linux"
        # Optional fields
        allowed_virtual_guest_ids = [ 27699397 ]
        allowed_ip_addresses = ["10.40.98.193", "10.40.98.200"]
        snapshot_capacity = 10
        hourly_billing = true
}

如需引數及屬性的相關資訊,請參閱 ibm_storage_block。

每個區塊磁區的授權數目預設限制是 8。 這表示最多可授權 8 台主機存取 Block Storage for Classic 磁碟區。 在 VMWare 部署中使用 Block Storage for Classic 的客戶,可以要求將授權限制提高到 64。 若要要求增加限制,請提出 支援案例。

若要從主機移除授權,請從 ibm_storage_block 資源移除其詳細資料,並套用您的變更。

在控制台中檢視獲授權存取 Block Storage for Classic 卷的主機清單

  1. 點選「儲存空間」> Block Storage for Classic,然後點選您的磁碟區名稱。
  2. 按一下 授權主機,以顯示有權存取磁區的計算實例清單。
  3. 點擊省略號操作圖示 並選擇查看主機詳細資料。 顯示側面板,其中包含裝置名稱、IP 位址、使用者名稱和密碼、主機 IQN 和裝置類型等詳細資訊。 啟用 ISCSI 隔離後,也會顯示存取控制清單部分。 您可以在 Access Control List(存取控制清單)區段中新增或移除子網路。

「目標」位址列在儲存空間詳細資料頁面。 對於 Block Storage,它是 Discover Target Portal 的 IP 位址。 對於 File Storage,目標位址會以 DNS 名稱描述。

在控制台中更新主機授權

  1. 點選「儲存空間」> Block Storage for Classic,然後點選您的磁碟區名稱。
  2. 按一下 授權主機,以顯示有權存取磁區的計算實例清單。
  3. 點擊省略號操作圖示 並選擇新增子網路。 僅當啟用 ISCSI 隔離時,此選項才可用。
  4. 在新對話方塊中,從清單中選擇要新增的子網路。
  5. 按一下提交。

透過 CLI 檢視獲授權存取 Block Storage for Classic 卷的宿主清單

從 IBMCLOUD CLI 檢視授權主機清單

若要確認授權已運作,請執行 ibmcloud sl block access-list 指令。

ibmcloud sl block access-list 12345678 --sortby allowed_host_id

從 SLCLI 檢視授權主機清單

若要查看目前授權存取磁碟區的主機清單,您可以使用下列指令。

$ slcli block access-list --help
Usage: slcli block access-list [OPTIONS] VOLUME_ID
Options:
  --sortby TEXT   Column to sort by
  --columns TEXT  Columns to display. Options: id, name, type,
                  private_ip_address, source_subnet, host_iqn, username,
                  password, allowed_host_id
  -h, --help      Show this message and exit.

使用 Terraform 檢視獲授權存取 Block Storage for Classic 卷的宿主清單

儲存資源建立後,您可以檢視 allowed_host_info 屬性,其中包含使用者名稱、密碼,以及授權存取磁碟區的 Compute 主機的 IQN。

如需引數及屬性的相關資訊,請參閱 ibm_storage_block。

查看Block Storage for Classic控制台中授權主機的權限

您可以檢視主機可存取的儲存體,其中包括建立連線所需的資訊——LUN 名稱、儲存類型、目標位址、容量及位置:

  1. 在 IBM Cloud® 控制台中,按一下「裝置」>「裝置清單」,然後按一下相應的裝置。
  2. 選取儲存空間標籤。

系統會顯示一份此特定主機可存取的儲存卷清單。 此清單是依儲存空間類型(區塊、檔案、其他)分組。 您可以按一下動作來授權更多儲存空間或移除存取權。

同一台主機不得同時獲授權存取不同作業系統類型的磁碟區。 可授權某台主機存取單一作業系統類型的磁碟區。 若您嘗試授權某台主機存取多個作業系統類型不同的磁碟區,該操作將會導致錯誤。

撤銷主機的存取權限Block Storage for Classic在控制台中

如果您要停止主機對特定儲存空間磁區的存取權,則可以撤銷存取權。 撤銷存取權限後,該主機的連線將從卷中移除。 該主機上的作業系統和應用程式已無法與該磁碟區進行通訊。

為避免主機端問題,請在撤銷存取權限前,先從作業系統中卸載儲存卷,以免發生磁碟遺失或資料損毀的情況。

您可以從裝置清單或儲存空間視圖中,撤銷存取權。

從裝置清單撤銷存取權

  1. 在 IBM Cloud® 主控台中,按一下「標準基礎架構」圖示。 接著,請按一下「裝置」>「裝置清單」,然後雙擊相應的裝置。
  2. 選取儲存空間標籤。
  3. 系統會顯示一份此特定主機可存取的儲存卷清單。 此清單是依儲存空間類型(區塊、檔案、其他)分組。 在磁區名稱旁,按一下動作,然後按一下撤銷存取權。
  4. 請確認您確實要撤銷對該卷的存取權限,因為此操作無法撤銷。 按一下 「是」 以撤銷對該磁碟區的存取權限,或按一下「否」以取消此操作。

如果您要中斷多個磁區與特定主機的連線,則需要對每個磁區重複「撤銷存取權」動作。

從儲存空間視圖撤銷存取權

  1. 按一下「儲存空間」> Block Storage for Classic,然後選取您要撤銷存取權限的儲存卷。
  2. 按一下 授權主機。
  3. 點擊要撤銷其存取權限的主機旁邊的「動作 「動作」圖示」,然後選擇「撤銷存取權限」。
  4. 請確認您確實要撤銷對該卷的存取權限,因為此操作無法撤銷。 按一下 「是」 以撤銷對該磁碟區的存取權限,或按一下「否」以取消此操作。

如果您要中斷多個主機與特定磁區的連線,則需要對每個主機重複「撤銷存取權」動作。

從 CLI 撤銷存取權。

如果您要停止主機對特定儲存空間磁區的存取權,則可以撤銷存取權。 撤銷存取權限後,該主機的連線將從卷中移除。 該主機上的作業系統和應用程式已無法與該磁碟區進行通訊。

為避免主機端問題,請在撤銷存取權限前,先從作業系統中卸載儲存卷,以免發生磁碟遺失或資料損毀的情況。

撤銷來自 IBMCLOUD CLI 的存取權

使用下列指令,以撤銷來自 Compute 主機的存取權。 在下列範例中,從虛擬伺服器實例 87654321 撤銷對磁區 12345678 的存取權。

ibmcloud sl block access-revoke 12345678 --virtual-id 87654321

如需此指令可用的所有參數的相關資訊,請參閱 ibmcloud sl block access-revoke。

從 SLCLI 撤銷存取權限

使用下列指令,以撤銷來自 Compute 主機的存取權。

$ slcli block access-revoke --help
Usage: slcli block access-revoke [OPTIONS] VOLUME_ID
Options:
  -h, --hardware-id TEXT    The ID of a hardware server to revoke authorization.
  -v, --virtual-id TEXT     The ID of a virtual server to revoke authorization.
  -i, --ip-address-id TEXT  The ID of an IP address to revoke authorization.
  -p, --ip-address TEXT     An IP address to revoke authorization.
  --help                    Show this message and exit.

刪除儲存卷

有關安全停用並刪除「Block Storage for Classic」卷的步驟(包括一份可協助您避免意外資料遺失的刪除前檢查清單),請參閱 《停用與刪除「Block Storage for Classic」卷》。